/*
 *   Created the 2 April 2006
 *
 *   Azuki Framework
 *   Copyright 2006 the original author or authors.
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *   
 *   Contact : support@azuki-framework.org
 */

package org.azuki.bean.tutorial ;

import java.lang.reflect.Method;
import java.util.Map;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.*;

import org.azuki.bean.tutorial.MethodCounterAdvice.Counter;
import org.azuki.framework.annotation.MethodInfo;
import org.azuki.framework.aop.*;
import org.azuki.framework.bean.*;

/**
* @author Robert Bakic
*/

public class MethodCounter implements IAspect
{
	final public Object createAdvice(IPointcut ipc)
	throws Exception
	{
		Method[] meths = ipc.getSelectedMethods() ;
		return new MethodCounterAdvice(meths);
	}
	
	@MethodInfo(desc="This method match the contract for the request dispatcher")
	final public void service(HttpServlet servlet, HttpServletRequest req, HttpServletResponse res)
	throws Exception
	{
		ServletOutputStream out = res.getOutputStream() ;
		
		out.println("<html><head><title>Method invocation summary</title></head><body>");
		out.println("<table border>") ;
		
		// Header 
		printLine(out, "<h3>Methods</h3>", "<h3>Calls</h3>") ;
		
		// Getting information about the current bean 'aspect'
		IMetadata meta = Bean.getMetadata(this) ;
		
		// For each pointcut created using this aspect
		for(IPointcut pc : Bean.getPointcuts(meta.getID()))
		{
			// Gets the code advice
			MethodCounterAdvice mca = (MethodCounterAdvice)pc.getAdvice() ; 
		
			// For each counter stored in the code advice
			for(Map.Entry<String, Counter> ety : mca.getValues().entrySet())
				printLine(out, ety.getKey(), String.valueOf(ety.getValue().value())) ;
		}
		
		out.println("</table>") ;
	}	
	
	final static private void printLine(ServletOutputStream out, String key, String value)
	throws Exception
	{
		out.print("<tr>") ;
		out.print("<td>") ;
		out.print(key);
		out.print("</td>") ;
		out.print("<td>") ;
		out.print(value);
		out.print("</td>") ;
		out.println("</tr>") ;			
	}
}