/*
 *   Created the 2 April 2006
 *
 *   Azuki Framework
 *   Copyright 2006 the original author or authors.
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *   
 *   Contact : support@azuki-framework.org
 */

package org.azuki.bean.tutorial ;

import java.lang.reflect.Method;
import java.util.*;

import org.azuki.framework.injection.*;

/**
* @author Robert Bakic
*/

public class MethodCounterAdvice implements IController
{
	final private Map<String, Counter> calls = new HashMap<String,Counter>() ;
	final public Map<String, Counter> getValues() { return calls; }
	
	public MethodCounterAdvice(Method[] meths)
	{
		if(meths==null) return ;
		
		for(Method meth : meths)
			calls.put(meth.getName(), new Counter()) ;
	}

	final public Object intercept(InvocationTarget target)
	throws Exception 
	{
		Counter count = calls.get(target.getMethodName()) ;
		if(count!=null) count.next() ; // adds 1, thread safe
		 
		return target.proceed() ; // Just forward the request
	}
	
	// Simple counter
	public class Counter
	{
		private int counter = 0 ;
		final public int next() { return counter++ ; }
		final public int value() { return counter; }
	}	
}