/*
 *   Created the 2 April 2006
 *
 *   Azuki Framework
 *   Copyright 2006 the original author or authors.
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *   
 *   Contact : support@azuki-framework.org
 */

package org.azuki.bean.tutorial ;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.*;

import org.azuki.framework.annotation.MethodInfo;
import org.azuki.framework.injection.IMethodProxy;
import org.azuki.framework.injection.IMethodProxy.*;


/**
* @author Robert Bakic
*/
public class PriceServlet
{
	@DependencyInjectionInfo(desc="Inject here the discount calculation algorithm", param={Double.class})
	public IMethodProxy<Double> calculateDiscount = null ;
	
	@MethodInfo(desc="This method is the contract for the request dispatcher")
	public void service(HttpServlet servlet, HttpServletRequest req, HttpServletResponse res)
	throws Exception
	{
		ServletOutputStream out = res.getOutputStream();
		
		out.println("<html><head><title>Get discount value</title></head><body>");
		
		String action = req.getParameter("action");
		
		
		if (action!=null && action.equals("calculate"))
		{
			try
			{
				String sprice = req.getParameter("price") ;
				double price = Double.parseDouble(sprice);
		
				Double discount = calculateDiscount.call(new Double(price)) ;
				
				printDiscount(out, discount.doubleValue()) ;
				
				return;
			}
			catch(Exception e)
			{
				out.println("ERROR : Enter a valid price(number) !");
			}
		}

		printPriceForm(out);
	
	}

	static private void printPriceForm(ServletOutputStream out)
	throws Exception
	{
		out.println("<h2>Calculate Discount:</h2>");
        out.println("<form>");
        out.println("Price : <input name='price' length='30' value=''/><br>");
        out.println("<input type='submit' name='action' value='calculate'/>");
        out.println("</form>");
	}

	static private void printDiscount(ServletOutputStream out, double discount)
	throws Exception
	{
		out.println("<h2>Discount = "+discount+"</h2>");
	}
}
